@@ -2,49 +2,45 @@
 
   License::
 
-    Copyright (C) 2015-2016 by Martin Scharrer <martin@scharrer-online.de>
+    MIT License
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
+    Copyright (c) 2015-2022 by Martin Scharrer <martin.scharrer@web.de>
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+    Permission is hereby granted, free of charge, to any person obtaining a copy of this software
+    and associated documentation files (the "Software"), to deal in the Software without
+    restriction, including without limitation the rights to use, copy, modify, merge, publish,
+    distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
+    Software is furnished to do so, subject to the following conditions:
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    The above copyright notice and this permission notice shall be included in all copies or
+    substantial portions of the Software.
+
+    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
+    BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+    NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+    DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 """
-import unittest
 import sys
-import random
+
 from crccheck import checksum
-from crccheck.checksum import ALLCHECKSUMCLASSES, Checksum32, Checksum, ChecksumXor
 from crccheck.base import CrccheckError
+from crccheck.checksum import ALLCHECKSUMCLASSES, Checksum32, Checksum, ChecksumXor
+from tests import TestCase, randbytes
 
-def randombytes(length):
-    return [random.randint(0, 255) for n in range(0, length)]
 
-class TestChecksum(unittest.TestCase):
+class TestChecksum(TestCase):
 
     def test_allchecksums_bigendian(self):
-        def selftest_bigendian(cls):
-            return cls.selftest(byteorder='big')
-
         for checksumclass in ALLCHECKSUMCLASSES:
             with self.subTest(checksumclass=checksumclass):
-                selftest_bigendian(checksumclass)
+                checksumclass.selftest(byteorder='big')
 
     def test_allchecksums_littleendian(self):
-        def selftest_littleendian(cls):
-            return cls.selftest(byteorder='little')
-
         for checksumclass in ALLCHECKSUMCLASSES:
             with self.subTest(checksumclass=checksumclass):
-                selftest_littleendian(checksumclass)
+                checksumclass.selftest(byteorder='little')
 
     # noinspection PyProtectedMember
     def test_allchecksums_fail(self):
@@ -65,17 +61,17 @@ class TestChecksum(unittest.TestCase):
         Checksum32.calc(bytearray.fromhex("12345678909876543210"))
 
     def test_bytes(self):
-        if sys.version_info < (3, 3, 0):
+        if sys.version_info < (3, 3, 0):  # pragma: no cover
             raise self.skipTest("")
         Checksum32.calc(bytes.fromhex("12345678909876543210"))
 
     def test_string1(self):
-        if sys.version_info < (3, 3, 0):
+        if sys.version_info < (3, 3, 0):  # pragma: no cover
             raise self.skipTest("")
         Checksum32.calc(b"Teststring")
 
     def test_string3(self):
-        if sys.version_info < (3, 3, 0):
+        if sys.version_info < (3, 3, 0):  # pragma: no cover
             raise self.skipTest("")
         Checksum32.calc("Teststring".encode(), )
 
@@ -90,18 +86,14 @@ class TestChecksum(unittest.TestCase):
 
     def test_general_checksum_invalid_width(self):
         for n in (0, 1, 7, 9, 33):
-            try:
+            with self.assertRaises(ValueError):
                 Checksum(n)
-            except ValueError:
-                pass
-            else:
-                raise Exception
 
     def test_general_checksum_ident(self):
-        data = randombytes(1024)
-        assert checksum.Checksum32.calc(data) == checksum.Checksum(32).process(data).final()
-        assert checksum.Checksum16.calc(data) == checksum.Checksum(16).process(data).final()
-        assert checksum.Checksum8.calc(data) == checksum.Checksum(8).process(data).final()
+        data = randbytes(1024)
+        self.assertEqual(checksum.Checksum32.calc(data), checksum.Checksum(32).process(data).final())
+        self.assertEqual(checksum.Checksum16.calc(data), checksum.Checksum(16).process(data).final())
+        self.assertEqual(checksum.Checksum8.calc(data), checksum.Checksum(8).process(data).final())
 
     def test_general_checksumxor_valid_width(self):
         """ Checksum()
@@ -114,15 +106,11 @@ class TestChecksum(unittest.TestCase):
 
     def test_general_checksumxor_invalid_width(self):
         for n in (0, 1, 7, 9, 33):
-            try:
+            with self.assertRaises(ValueError):
                 ChecksumXor(n)
-            except ValueError:
-                pass
-            else:
-                raise Exception
 
     def test_general_checksumxor_ident(self):
-        data = randombytes(1024)
-        assert checksum.ChecksumXor32.calc(data) == checksum.ChecksumXor(32).process(data).final()
-        assert checksum.ChecksumXor16.calc(data) == checksum.ChecksumXor(16).process(data).final()
-        assert checksum.ChecksumXor8.calc(data) == checksum.ChecksumXor(8).process(data).final()
+        data = randbytes(1024)
+        self.assertEqual(checksum.ChecksumXor32.calc(data), checksum.ChecksumXor(32).process(data).final())
+        self.assertEqual(checksum.ChecksumXor16.calc(data), checksum.ChecksumXor(16).process(data).final())
+        self.assertEqual(checksum.ChecksumXor8.calc(data), checksum.ChecksumXor(8).process(data).final())
